==> ssp-center-api-0.5.60-yt-20190827.085840-23-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActRatioRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

public class ActRatioRsp implements Serializable {

	private static final long serialVersionUID = -2780966529468546895L;
	/** 排序序号 **/
	private int index;
	/**活动组id*/
    private Long actGroupId;
	/** 活动id **/
	private long activityId;
	/** 活动来源 **/
	private int actSource;
	/** 活动类型 **/
	private int actType;
	/** 活动名称  **/
	private String actName;
	/** 活动皮肤类型 **/
	private String subType;
	/** 活动皮肤 **/
	private String actSkin;
	/** 计划状态 **/
	private int planStatus;
	/** 流量比例  **/
	private int ratio;
	/** 是否默认：1默认 **/
	private int isDefault;
	/** 活动归属：0媒体运营，1活动运营 **/
	private int belongTo;
	/**1活动诶广告位屏蔽**/
	private Integer shieldActTagFlag;
	private String tag;
	private Integer overseas;
	/** 素材数量：活动素材+广告位定制素材 */
	private int itemContentAmount;
	 /**是否包含素材 0包含 1未包含*/
    private Integer           includeMaterial;
	/**
	 * 广告位地域类型ID
	 */
	private Long regionId;

	private Byte belongToGroup;
    /**版本验证*/
	private boolean notice = false;


	public boolean isNotice() {
		return notice;
	}

	public void setNotice(boolean notice) {
		this.notice = notice;
	}

	public Long getRegionId() {
		return regionId;
	}

	public void setRegionId(Long regionId) {
		this.regionId = regionId;
	}

	public Integer getIncludeMaterial() {
        return includeMaterial;
    }
    
    public void setIncludeMaterial(Integer includeMaterial) {
        this.includeMaterial = includeMaterial;
    }
    public int getIndex() {
		return index;
	}
	public void setIndex(int index) {
		this.index = index;
	}
	public Long getActGroupId() {
		return actGroupId;
	}
	public void setActGroupId(Long actGroupId) {
		this.actGroupId = actGroupId;
	}
	public long getActivityId() {
		return activityId;
	}
	public void setActivityId(long activityId) {
		this.activityId = activityId;
	}
	public int getActSource() {
		return actSource;
	}
	public void setActSource(int actSource) {
		this.actSource = actSource;
	}
	public String getActName() {
		return actName;
	}
	public void setActName(String actName) {
		this.actName = actName;
	}
	public String getActSkin() {
		return actSkin;
	}
	public void setActSkin(String actSkin) {
		this.actSkin = actSkin;
	}
	public int getPlanStatus() {
		return planStatus;
	}
	public void setPlanStatus(int planStatus) {
		this.planStatus = planStatus;
	}
	public int getRatio() {
		return ratio;
	}
	public void setRatio(int ratio) {
		this.ratio = ratio;
	}
	public int getIsDefault() {
		return isDefault;
	}
	public void setIsDefault(int isDefault) {
		this.isDefault = isDefault;
	}
	public int getBelongTo() {
		return belongTo;
	}
	public void setBelongTo(int belongTo) {
		this.belongTo = belongTo;
	}
	public int getActType() {
		return actType;
	}
	public void setActType(int actType) {
		this.actType = actType;
	}
	public String getSubType() {
		return subType;
	}
	public void setSubType(String subType) {
		this.subType = subType;
	}
	public Integer getShieldActTagFlag() {
		return shieldActTagFlag;
	}
	public void setShieldActTagFlag(Integer shieldActTagFlag) {
		this.shieldActTagFlag = shieldActTagFlag;
	}
	public String getTag() {
		return tag;
	}
	public void setTag(String tag) {
		this.tag = tag;
	}

	public Integer getOverseas() {
		return overseas;
	}

	public void setOverseas(Integer overseas) {
		this.overseas = overseas;
	}
	public int getItemContentAmount() {
		return itemContentAmount;
	}
	public void setItemContentAmount(int itemContentAmount) {
		this.itemContentAmount = itemContentAmount;
	}

	public Byte getBelongToGroup() {
		return belongToGroup;
	}

	public void setBelongToGroup(final Byte belongToGroup) {
		this.belongToGroup = belongToGroup;
	}
}

==> ssp-center-api-0.5.61-yt2-20190905.092146-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActRatioRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

public class ActRatioRsp implements Serializable {

	private static final long serialVersionUID = -2780966529468546895L;
	/** 排序序号 **/
	private int index;
	/**活动组id*/
    private Long actGroupId;
	/** 活动id **/
	private long activityId;
	/** 活动来源 **/
	private int actSource;
	/** 活动类型 **/
	private int actType;
	/** 活动名称  **/
	private String actName;
	/** 活动皮肤类型 **/
	private String subType;
	/** 活动皮肤 **/
	private String actSkin;
	/** 计划状态 **/
	private int planStatus;
	/** 流量比例  **/
	private int ratio;
	/** 是否默认：1默认 **/
	private int isDefault;
	/** 活动归属：0媒体运营，1活动运营 **/
	private int belongTo;
	/**1活动诶广告位屏蔽**/
	private Integer shieldActTagFlag;
	private String tag;
	private Integer overseas;
	/** 素材数量：活动素材+广告位定制素材 */
	private int itemContentAmount;
	 /**是否包含素材 0包含 1未包含*/
    private Integer           includeMaterial;
	/**
	 * 广告位地域类型ID
	 */
	private Long regionId;

	private Byte belongToGroup;
    /**版本验证*/
	private boolean notice = false;
	/* 是否支持增值 0-否 1-是*/
	private Integer isEnc;

	public boolean isNotice() {
		return notice;
	}

	public void setNotice(boolean notice) {
		this.notice = notice;
	}

	public Long getRegionId() {
		return regionId;
	}

	public void setRegionId(Long regionId) {
		this.regionId = regionId;
	}

	public Integer getIncludeMaterial() {
        return includeMaterial;
    }
    
    public void setIncludeMaterial(Integer includeMaterial) {
        this.includeMaterial = includeMaterial;
    }
    public int getIndex() {
		return index;
	}
	public void setIndex(int index) {
		this.index = index;
	}
	public Long getActGroupId() {
		return actGroupId;
	}
	public void setActGroupId(Long actGroupId) {
		this.actGroupId = actGroupId;
	}
	public long getActivityId() {
		return activityId;
	}
	public void setActivityId(long activityId) {
		this.activityId = activityId;
	}
	public int getActSource() {
		return actSource;
	}
	public void setActSource(int actSource) {
		this.actSource = actSource;
	}
	public String getActName() {
		return actName;
	}
	public void setActName(String actName) {
		this.actName = actName;
	}
	public String getActSkin() {
		return actSkin;
	}
	public void setActSkin(String actSkin) {
		this.actSkin = actSkin;
	}
	public int getPlanStatus() {
		return planStatus;
	}
	public void setPlanStatus(int planStatus) {
		this.planStatus = planStatus;
	}
	public int getRatio() {
		return ratio;
	}
	public void setRatio(int ratio) {
		this.ratio = ratio;
	}
	public int getIsDefault() {
		return isDefault;
	}
	public void setIsDefault(int isDefault) {
		this.isDefault = isDefault;
	}
	public int getBelongTo() {
		return belongTo;
	}
	public void setBelongTo(int belongTo) {
		this.belongTo = belongTo;
	}
	public int getActType() {
		return actType;
	}
	public void setActType(int actType) {
		this.actType = actType;
	}
	public String getSubType() {
		return subType;
	}
	public void setSubType(String subType) {
		this.subType = subType;
	}
	public Integer getShieldActTagFlag() {
		return shieldActTagFlag;
	}
	public void setShieldActTagFlag(Integer shieldActTagFlag) {
		this.shieldActTagFlag = shieldActTagFlag;
	}
	public String getTag() {
		return tag;
	}
	public void setTag(String tag) {
		this.tag = tag;
	}

	public Integer getOverseas() {
		return overseas;
	}

	public void setOverseas(Integer overseas) {
		this.overseas = overseas;
	}
	public int getItemContentAmount() {
		return itemContentAmount;
	}
	public void setItemContentAmount(int itemContentAmount) {
		this.itemContentAmount = itemContentAmount;
	}

	public Integer getIsEnc() {
		return isEnc;
	}

	public void setIsEnc(Integer isEnc) {
		this.isEnc = isEnc;
	}

	public Byte getBelongToGroup() {
		return belongToGroup;
	}

	public void setBelongToGroup(final Byte belongToGroup) {
		this.belongToGroup = belongToGroup;
	}
}
